import { createRoot } from "react-dom/client";
import "./index.css";
import { Helmet, HelmetProvider } from "react-helmet-async";
import App from "./App";

// Add performance monitoring
const reportWebVitals = () => {
  if ('performance' in window && 'timing' in window.performance) {
    window.addEventListener('load', () => {
      setTimeout(() => {
        const timing = window.performance.timing;
        const pageLoadTime = timing.loadEventEnd - timing.navigationStart;
        console.debug("Page load time:", pageLoadTime + "ms");
        
        // Could send to Google Analytics
        if (window.gtag) {
          window.gtag('event', 'timing_complete', {
            name: 'page_load',
            value: pageLoadTime,
            event_category: 'Performance'
          });
        }
      }, 0);
    });
  }
};

createRoot(document.getElementById("root")!).render(
  <HelmetProvider>
    <Helmet>
      <title>Podcast Studio London - Professional Recording & Production Services</title>
      <meta name="description" content="Leading podcast recording studio in London offering professional audio production, sound engineering, and podcast creation services. Book your session today." />
      <meta name="keywords" content="podcast studio london, podcast recording, audio production, sound engineering, podcast creation, professional studio" />
      <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=5" />
      <meta name="robots" content="index, follow, max-snippet:-1, max-image-preview:large, max-video-preview:-1" />
      <meta name="googlebot" content="index, follow" />
      <link rel="canonical" href="https://workspace.shanewpowell.replit.dev" />
      
      {/* Preconnect to external domains for performance */}
      <link rel="preconnect" href="https://fonts.googleapis.com" />
      <link rel="preconnect" href="https://fonts.gstatic.com" crossOrigin="" />
      <link rel="preconnect" href="https://www.googletagmanager.com" />
      <link rel="dns-prefetch" href="//www.google-analytics.com" />
      
      {/* Optimized font loading */}
      <link href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700&display=swap" rel="stylesheet" />
      
      {/* Performance hints */}
      <meta httpEquiv="x-dns-prefetch-control" content="on" />
      
      {/* Open Graph tags for better social sharing */}
      <meta property="og:title" content="Podcast Studio London - Professional Recording Services" />
      <meta property="og:description" content="Leading podcast recording studio in London with state-of-the-art equipment and expert sound engineers. Create professional podcasts with us." />
      <meta property="og:type" content="website" />
      <meta property="og:url" content="https://workspace.shanewpowell.replit.dev" />
      <meta property="og:image" content="/assets/images/podcast-studio-logo-original.jpg" />
      <meta property="og:image:width" content="1200" />
      <meta property="og:image:height" content="630" />
      <meta property="og:site_name" content="Podcast Studio London" />
      <meta property="og:locale" content="en_GB" />
      
      {/* Twitter Card tags */}
      <meta name="twitter:card" content="summary_large_image" />
      <meta name="twitter:title" content="Podcast Studio London - Professional Recording Services" />
      <meta name="twitter:description" content="Leading podcast recording studio in London with state-of-the-art equipment and expert sound engineers." />
      <meta name="twitter:image" content="/assets/images/podcast-studio-logo-original.jpg" />
      
      {/* Structured data for SEO */}
      <script type="application/ld+json">
        {JSON.stringify({
          "@context": "https://schema.org",
          "@type": "LocalBusiness",
          "name": "Podcast Studio London",
          "description": "Professional podcast recording and production studio in London",
          "url": "https://workspace.shanewpowell.replit.dev",
          "telephone": "+44-20-XXXX-XXXX",
          "address": {
            "@type": "PostalAddress",
            "streetAddress": "London",
            "addressLocality": "London",
            "addressCountry": "GB"
          },
          "geo": {
            "@type": "GeoCoordinates",
            "latitude": "51.5074",
            "longitude": "-0.1278"
          },
          "openingHours": "Mo-Fr 09:00-18:00",
          "priceRange": "££",
          "serviceArea": {
            "@type": "GeoCircle",
            "geoMidpoint": {
              "@type": "GeoCoordinates",
              "latitude": "51.5074",
              "longitude": "-0.1278"
            },
            "geoRadius": "50000"
          }
        })}
      </script>
    </Helmet>
    <App />
  </HelmetProvider>
);

// Optional: Monitor and report performance metrics
reportWebVitals();
